#ifndef KYSEC_TEE_DEF_H__
#define KYSEC_TEE_DEF_H__

#include <stdint.h>

typedef uint32_t KT_Result;

#define KT_SUCCESS                              0x00000000              //成功

#define KT_TEEC_ERROR_STORAGE_NOT_AVAILABLE     0xF0100003
#define KT_TEEC_ERROR_GENERIC                   0xFFFF0000
#define KT_TEEC_ERROR_ACCESS_DENIED             0xFFFF0001
#define KT_TEEC_ERROR_CANCEL                    0xFFFF0002
#define KT_TEEC_ERROR_ACCESS_CONFLICT           0xFFFF0003
#define KT_TEEC_ERROR_EXCESS_DATA               0xFFFF0004
#define KT_TEEC_ERROR_BAD_FORMAT                0xFFFF0005
#define KT_TEEC_ERROR_BAD_PARAMETERS            0xFFFF0006
#define KT_TEEC_ERROR_BAD_STATE                 0xFFFF0007
#define KT_TEEC_ERROR_ITEM_NOT_FOUND            0xFFFF0008
#define KT_TEEC_ERROR_NOT_IMPLEMENTED           0xFFFF0009
#define KT_TEEC_ERROR_NOT_SUPPORTED             0xFFFF000A
#define KT_TEEC_ERROR_NO_DATA                   0xFFFF000B
#define KT_TEEC_ERROR_OUT_OF_MEMORY             0xFFFF000C
#define KT_TEEC_ERROR_BUSY                      0xFFFF000D
#define KT_TEEC_ERROR_COMMUNICATION             0xFFFF000E
#define KT_TEEC_ERROR_SECURITY                  0xFFFF000F
#define KT_TEEC_ERROR_SHORT_BUFFER              0xFFFF0010
#define KT_TEEC_ERROR_EXTERNAL_CANCEL           0xFFFF0011
#define KT_TEEC_ERROR_TARGET_DEAD               0xFFFF3024
#define KT_TEEC_ERROR_SDK                       0xFFFE0000

#define KT_BASE_ERROR_EINVAL                    0xFF100001
#define KT_BASE_ERROR_EINLEN                    0xFF100002

#define KT_SIGN_ERROR_AUTH_ERROR                0xFF101001
#define KT_SIGN_ERROR_AUTH_FAILED               0xFF101002
#define KT_SIGN_ERROR_CERT_MISMATCH             0xFF101003
#define KT_SIGN_ERROR_CERT_FINGER               0xFF101004
#define KT_SIGN_ERROR_APP_PATH                  0xFF101005

// secure data 错误
#define KT_SOS_BAD_METADATA                     0xFF010000
#define KT_SOS_PERM_NOT_SUPPORTED               0xFF010001
#define KT_SOS_SDATA_ID_INVALID_LENGTH          0xFF010002
#define KT_SOS_SDATA_PAYLOAD_INVALID_LENGTH     0xFF010003
#define KT_SOS_SDATA_AUTH_FAILED                0xFF010004
#define KT_SOS_SDATA_KEY_TYPE_NOT_SUPPORTED     0xFF010005

// key manager 错误
#define KT_KM_KEY_MANAGER_INNER_DATA_ERROR      0xFF020000

//algo 错误
#define E_CRYPTO_CBC_WITH_NO_IV                 0xFF030000
#define E_CRYPTO_ECB_WITH_IV                    0xFF030001
#define E_CRYPTO_SM2_INVALID_ENCRYPTED_SIZE     0xFF030002
#define E_CRYPTO_SM2_GENERATE                   0xFF030003

//数据载荷
typedef struct KYSEC_TEE_DATA {
        uint8_t *dptr;                          //数据
        uint32_t dsize;                         //数据长度
} KYSEC_TEE_DATA;

#define SOS_ID_MAX_LEN  32                              //安全存储ID最大长度
typedef unsigned char SOS_ID[SOS_ID_MAX_LEN + 1];       //安全存储对象ID

#define KM_ID_MAX_LEN  32                               //密钥管理对象ID最大长度
typedef unsigned char KM_ID[KM_ID_MAX_LEN + 1];         //密钥存储ID

//SM3算法上下文
typedef struct ALGO_SM3_CTX {                           
        uint8_t content[128];
        uint8_t ctx[128];
}ALGO_SM3_CTX;

//SM4算法上下文
typedef struct ALGO_SM4_CTX {
        uint8_t content[256];
        uint8_t ctx[128];       
}ALGO_SM4_CTX;

//SM4算法模式
typedef enum ALGO_SM4_OP_MODE {
      SM4_MODE_ECB          = 0,                        //ECB模式
      SM4_MODE_CBC           ,                          //CBC模式
      SM4_MODE_MAX
}ALGO_SM4_OP_MODE;

//SM4算法类型
typedef enum ALGO_SM4_OP_TYPE {
      SM4_CRYPTO_ENCRYPT    = 0,                        // 加密
      SM4_CRYPTO_DECRYPT      ,                         // 解密
      SM4_CRYPTO_MAX
}ALGO_SM4_OP_TYPE;

#endif