#ifndef KYSEC_TEE_KM_H__
#define KYSEC_TEE_KM_H__

#include <kysec_tee_def.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief TEE内部生成sm2公私钥对
 * 
 * @param km_id 密钥管理sm2公私钥对ID
 * @param pub_key 传出，sm2公钥
 * @return 0 成功，其他失败 
 */
extern KT_Result kysec_tee_km_sm2_keygen(const KM_ID km_id, uint8_t pub_key[64]);

/**
 * @brief TEE内部sm2对象签名
 * 
 * @param km_id 密钥管理sm2公私钥对ID
 * @param data 待签名数据
 * @param sign_data 传出，签名
 * @return 0 成功，其他失败  
 */
extern KT_Result kysec_tee_km_sm2_sign(const KM_ID km_id, KYSEC_TEE_DATA data, uint8_t sign_data[64]);

/**
 * @brief TEE内部sm2对象验签
 * 
 * @param km_id 密钥管理sm2公私钥对ID
 * @param data 待验签数据
 * @param sign_data 签名
 * @return 0 验签通过， 1 验签失败， 其他 接口调用失败 
 */
extern KT_Result kysec_tee_km_sm2_verify(const KM_ID km_id, KYSEC_TEE_DATA data, uint8_t sign_data[64]);

#ifdef __cplusplus
}
#endif

#endif