#ifndef KYSEC_TEE_SOS_H__
#define KYSEC_TEE_SOS_H__

#include <kysec_tee_def.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 存储数据至TEE
 * 
 * @param sec_obj_id 安全存储对象ID
 * @param data 待存储数据
 * @return 0 成功， 其他失败
 */
extern KT_Result kysec_tee_sos_store(const SOS_ID sec_obj_id, const KYSEC_TEE_DATA data);

/**
 * @brief 更新TEE中存储数据
 * 
 * @param sec_obj_id 安全存储对象ID
 * @param data 待更新数据
 * @return 0 成功， 其他失败 
 */
extern KT_Result kysec_tee_sos_update(const SOS_ID sec_obj_id, const KYSEC_TEE_DATA data);

/**
 * @brief 删除TEE中存储数据
 * 
 * @param sec_obj_id 安全存储对象ID
 * @return 0 成功， 其他失败 
 */
extern KT_Result kysec_tee_sos_delete(const SOS_ID sec_obj_id);

/**
 * @brief 获取TEE中制定ID对应数据载荷
 * 
 * @param sec_obj_id 安全存储对象ID
 * @param data 获取到载荷数据，dptr指向内存接口内部申请，使用完成后，需外部释放
 * @return 0 成功， 其他失败 
 */
extern KT_Result kysec_tee_sos_fetch(const SOS_ID sec_obj_id, KYSEC_TEE_DATA *data);

#ifdef __cplusplus
}
#endif

#endif